#################################
# Jana2000 makefile for OpenVMS #
#################################


UNDERSCORES = undef            # don't change this setting
LOWER_CASE = undef             # don't change this setting
UPPER_CASE = undef             # don't change this setting
MIXED_CASE = undef             # don't change this setting
FTN_SUFFIX = f                 # don't change this setting
FOPT1 =                        # don't change this setting
FSPLIT = mcr [-.specific]sekej  # don't change this setting
WARN =
WATCH = none
CCKR = 
PSCOMMAND = sh sys

#####################################
# Please check following 5 settings #
#####################################

## --> 1. list of programs to compile
COMPONENTS = chargeden contour datred dist editm40 editm50 editm9 fourier \
             glib grapht jana2000 janalib crystlib pictur pwdlib refine
## --> 2. path to source directories of Jana (relative or absolute)
JPATH = [.source]
FGPATH = [.source.fg]
## --> 3. the command calling C compiler (without options)
CCOM = cc 
## --> 4. the command starting Bourne shell
## (if the make cannot load the shell, try to find it by command
##  "whereis sh")
SHELL = spawn
## --> 5. The application home directory 
## (path for outline fonts, configuration files etc.)
## The files for fg graphic library are in JANADIR/source/fg
## The files for Jana2000 are in JANADIR/source/data
JANADIR = JANA_HOME

## The command calling Fortran compiler (without options)
FCOM = fortran
## path to the C & Fortran include files
INCLUDE =/include=([.source],[.source.fg],[.vms],[.specific])
## Fortran compiler options
FOPTS = /opt $(WARN)$(INCLUDE)
## C compiler options
COPTS = /opt $(WARN) $(INCLUDE)
## libraries to link
LINKLIBS = [.vms]xlib/opt
## RANLIB is not used, but cannot be empty
RANLIB = write sys$output ""

PREPARE = prepare    # please don't change this setting
PROG = jana2000      # please don't change this setting
INFO = OpenVMS HP Fortran compiler # please don't change this setting

###############################################################
# Try to start make. Please contact the authors if it doesn't #
# run correctly.                                              #
# E-mail petricek@fzu.cz or dusek@fzu.cz                      #
###############################################################

# Please don't change the rest of the file unless it is 
# necessary

SPECIDIR = specific
SPECIFIC = [.$(SPECIDIR)]specific.h
FHEAD = [.$(SPECIDIR)]Fhead.h

JAKOLIB = pictur.obj,janalib.obj,pwdlib.obj
LIBS = jlibrary.olb fg.olb vmslib.olb
LIBSL = jlibrary.olb/lib,fg.olb/lib,vmslib/lib
OBJLIST = chargeden.obj,contour.obj,datred.obj,dist.obj,editm40.obj,editm50.obj,editm9.obj,\
          fourier.obj,grapht.obj,jana2000.obj,refine.obj

CMN =[.source]atoms.cmn [.source]basic.cmn [.source]const.cmn [.source]contour.cmn [.source]datred.cmn [.source]dist.cmn\
	[.source]editm40.cmn [.source]editm50.cmn [.source]editm9.cmn [.source]fepc.cmn [.source]fgids.cmn [.source]fourier.cmn\
	[.source]glib.cmn [.source]grapht.cmn [.source]main.cmn [.source]memexport.cmn [.source]molec.cmn [.source]params.cmn\
	[.source]params.cmn [.source]picfce.cmn [.source]pictur.cmn\
	[.source]powder.cmn [.source]profil.cmn [.source]refine.cmn\
	[.vms]appl_homedir.cmn [.vms]fg_homedir.cmn [.vms]fg_userfiles.cmn\
	[.vms]specific.cmn

#### end of macros definitions ####

all : $(PREPARE) $(PROG)
		@ pur [...]
		@ touch [.specific]splitfg.exe
		@ touch [.specific]MainUnit.c
		@ write sys$output "jana2000 build completed"

prepare : [.vms]getfsplit.exe [.vms]getmainunit.exe
		@ @[.vms]setname $(MMS$TARGET_NAME)
		@ write sys$output "$(INFO)"
		@ if f$search("d.dir") .eqs. "" then create/directory [.d]
		@ if f$search("specific.dir") .eqs. "" then create/directory [.specific]
		@ write sys$output "32 bits compilation"
		@ $(MMS) [.specific]splitfg.exe
		@ $(MMS) [.specific]MainUnit.c
		@ set def [.source]
		@ $(FCOM) $(FOPT1) sekej.f
		@ link sekej
		@ set def [-]

[.specific]MainUnit.c : [.source.fg]fg.src
		@ set default [.specific]
		@ run [-.vms]getmainunit.exe
		@ set def [-]

[.specific]splitfg.exe : [.source.fg]fg.src
		@ edit/edt/comma=[.vms]edt.ini [.source.fg]fg.src
		@ set default [.specific]
		@ type/tail=200 [-.source.fg]fg.src /outp=splitfg.f_
		@ run [-.vms]getfsplit.exe
		@ delete splitfg.f_;*
		@ $(FCOM) $(FOPT1) splitfg.$(FTN_SUFFIX)
		@ link splitfg
		@ set def [-]

[.vms]getfsplit.exe : [.vms]getfsplit.f90
		@ @[.vms]setname $(MMS$TARGET_NAME)
	f90/obj=[.vms]getfsplit.obj [.vms]getfsplit.f90
	link/exec=[.vms]getfsplit.exe [.vms]getfsplit.obj

[.vms]getmainunit.exe : [.vms]getmainunit.f90
		@ @[.vms]setname $(MMS$TARGET_NAME)
	f90/obj=[.vms]getmainunit.obj [.vms]getmainunit.f90
	link/exec=[.vms]getmainunit.exe [.vms]getmainunit.obj

jana2000 : MainUnit.obj $(OBJLIST) $(LIBS)
		@ @[.vms]setname $(MMS$TARGET_NAME)
		@ link/exec=jana2000.exe MainUnit,$(OBJLIST),$(LIBSL),$(LINKLIBS)

MainUnit.obj : [.specific]MainUnit.c
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(CCOM) $(COPTS) [.specific]$(MMS$TARGET_NAME).c

chargeden.obj : $(JPATH)chargeden.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

contour.obj : $(JPATH)contour.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

datred.obj : $(JPATH)datred.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

dist.obj : $(JPATH)dist.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

editm40.obj : $(JPATH)editm40.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

editm50.obj : $(JPATH)editm50.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

editm9.obj : $(JPATH)editm9.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

fourier.obj : $(JPATH)fourier.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

grapht.obj : $(JPATH)grapht.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

jana2000.obj : $(JPATH)jana2000.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
		@ pipe gsed -e "s/program Jana/subroutine Jana/"\
		$(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX) > $(MMS$TARGET_NAME).f_
           	@ $(FCOM) $(FOPTS) $(MMS$TARGET_NAME).f_

refine.obj : $(JPATH)refine.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

jlibrary.olb : $(JPATH)crystlib.f $(JPATH)glib.f $(JAKOLIB) $(CMN)
		@ @[.vms]setname $(MMS$TARGET_NAME)
		@ lib/crea jlibrary.olb
		@ set def [.d]
		@ copy [-.source]crystlib.f []
		@ fsplit crystlib.f
		@ delete crystlib.f;*
		@ @[-.vms]compile_crystlib
		@ delete *.*;*
		@ copy [-.source]glib.f []
		@ fsplit glib.f
		@ delete glib.f;*
		@ @[-.vms]compile_crystlib
		@ delete *.*;*
		@ set def [-]
		library jlibrary.olb $(JAKOLIB)

pictur.obj : $(JPATH)pictur.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

janalib.obj : $(JPATH)janalib.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

pwdlib.obj : $(JPATH)pwdlib.f $(CMN) 
		@ @[.vms]setname $(MMS$TARGET_NAME)
           	@ $(FCOM) $(FOPTS) $(JPATH)$(MMS$TARGET_NAME).$(FTN_SUFFIX)

fg.olb : $(FGPATH)fg.src $(FGPATH)fg.h [.source.data]bitdata.h $(CMN)
		@ @[.vms]setname $(MMS$TARGET_NAME)
		@ set def [.d]
		@ pipe run [-.specific]splitfg < [-.source.fg]fg.src
		@ @[-.vms]fg_build.com
		@ delete *.*;*
		@ set def [-]

vmslib.olb : [.vms]getenv.f90 [.vms]system.f90
		@ @[.vms]setname $(MMS$TARGET_NAME)
	f90 [.vms]getenv.f90
	f90 [.vms]system.f90
	library/create vmslib.olb getenv,system
